fix_all_results verifies that the results table has the correct format and p-values
.fix_all_results(all_results)the same data frame
a data frame containing the following columns
A string identifying the element of interest
The p-value of the element
The number of patients with a mutation in the element
The expected number of patients with a mutation in the element with respect to background
A boolean indicating whether the element is enriched in mutations
The p-value of the element
The number of patients with a mutation in the site
The expected number of patients with a mutation in the site with respect to element
A boolean indicating whether the site is enriched in mutations
A numeric indicator denoting the order in which the results were calculated