This function finds the tri-nucleotide context of mutations
.get_3n_context_of_mutations(mutations, this_genome)A data frame consisting of the same columns as the original mutations data frame and sorted
by SNVs and Indels with an additional column tag which indicates the trinucleotide context of
the mutation
A data frame with the following columns: chr, pos1, pos2, ref, alt, patient
autosomal chromosomes as chr1 to chr22 and sex chromosomes as chrX and chrY
the start position of the mutation in base 1 coordinates
the end position of the mutation in base 1 coordinates
the reference allele as a string containing the bases A, T, C or G
the alternate allele as a string containing the bases A, T, C or G
the patient identifier as a string
The reference genome object of BSgenome, for example BSgenome.Hsapiens.UCSC.hg19::Hsapiens