Splits a BED12 file into separate regions
.split_coord_fragments_in_BED(i, coords)A data frame containing the following columns for a given BED12 identifier
autosomal chromosomes as chr1 to chr22 and sex chromosomes as chrX and chrY
the start position of the element in base 0 coordinates (BED format)
the end position of the element in base 0 coordinates (BED format)
the element identifier - if the element contains multiple segments such as exons, each segment should be a separate row with the segment coordinates and the element identifier as id. Elements can be coding or noncoding such as exons of protein coding genes or active enhancers.
The i-th row of the coords data frame which needs to be split into separate elements
The coords data frame which is the imported BED12 file