protein coding genes from gencode v.19, cancer genes adapted from the Cancer Gene Census (November, 2018).
Genes affected solely by amplifications, deletions and translations were removed.
Usage
data(cancer_genes)
Arguments
Format
A data frame containing the following columns: chr, start, end, id
chr
autosomal chromosomes as chr1 to chr22 and sex chromosomes as chrX and chrY
start
the start position of the element in base 0 coordinates (BED format)
end
the end position of the element in base 0 coordinates (BED format)
id
the element identifier - if the element contains multiple segments such as exons, each segment should be a separate row with the segment coordinates and the element identifier as id. Elements can be coding or noncoding such as exons of protein coding genes or active enhancers.
References
Harrow, Jennifer, et al. "GENCODE: the reference human genome annotation for The ENCODE Project." Genome research 22.9 (2012): 1760-1774.
(PubMed)