.get_obs_exp: Calculates the number of expected mutations based
Description
Calculates the number of expected mutations based
Usage
.get_obs_exp(hyp, select_positions, dfr, colname)
Value
a list of observed mutations and expected mutations
Arguments
- hyp
hypothesis to be tested
- select_positions
boolean column which indicates which positions are in the element of interest
- dfr
a dataframe containing the data to be tested
- colname
name of the column which indicates the count of mutations in the positions of interest